Simple platformer game using the Ursina library
AI used for repeated autofill
DS4 WIndows supported
HOWT RUN 
 1.Open terminal and run : "git clone https://github.com/Damelhasen/Platformer"
 2.Enter the folder you cloned the repo to and run "pip install -r requirements.txt"
 3.Run MAIN.py
 5.Have FUN !